CHANGELOG
=========
* 0.2.1 (2021-11-29)
    * Fixed release

* 0.2.0 (2021-11-29)
    * An issue with the contact resource url was fixed

* 0.1.9 (2021-03-08)
    * Fixed header issue in delete methods

* 0.1.5 (2019-03-08)
    * Release
